==> libgwenhywfar_1.19.2.orig.tar.gz: gwenhywfar-1.19.2/src/os/windows/libloader_p.h <==
/***************************************************************************
  $RCSfile: libloader_p.h,v $
                             -------------------
    cvs         : $Id: libloader_p.h,v 1.6 2004/05/06 11:02:04 aquamaniac Exp $
    begin       : Fri Nov 22 2002
    copyright   : (C) 2002 by Martin Preuss
    email       : martin@libchipcard.de


 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef GWENHYWFAR_LIBLOADER_P_H
#define GWENHYWFAR_LIBLOADER_P_H "$Id"

#include <windows.h>
#include <gwenhywfar/gwenhywfarapi.h>
#include <gwenhywfar/error.h>
#include <gwenhywfar/libloader.h>


#ifdef __cplusplus
extern "C" {
#endif


GWENHYWFAR_API struct GWEN_LIBLOADERSTRUCT {
  void *handle;
};


GWEN_ERRORCODE GWEN_LibLoader_LoadLibrary(GWEN_LIBLOADER *h,
                                          const char *name);


#ifdef __cplusplus
}
#endif


#endif /* GWENHYWFAR_LIBLOADER_P_H */

==> libgwenhywfar_2.4.0.orig.tar.gz: gwenhywfar-2.4.0/src/os/windows/libloader_p.h <==
/***************************************************************************
  $RCSfile$
                             -------------------
    cvs         : $Id: libloader_p.h 923 2005-11-19 03:35:10Z aquamaniac $
    begin       : Fri Nov 22 2002
    copyright   : (C) 2002 by Martin Preuss
    email       : martin@libchipcard.de


 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef GWENHYWFAR_LIBLOADER_P_H
#define GWENHYWFAR_LIBLOADER_P_H "$Id"

#include <windows.h>
#include <gwenhywfar/gwenhywfarapi.h>
#include <gwenhywfar/error.h>
#include <gwenhywfar/libloader.h>


#ifdef __cplusplus
extern "C" {
#endif


GWENHYWFAR_API struct GWEN_LIBLOADERSTRUCT {
  void *handle;
};


GWEN_ERRORCODE GWEN_LibLoader_LoadLibrary(GWEN_LIBLOADER *h,
                                          const char *name);

GWEN_ERRORCODE GWEN_LibLoader__OpenLibraryWithPath(GWEN_LIBLOADER *h,
                                                   const char *path,
                                                   const char *name);


#ifdef __cplusplus
}
#endif


#endif /* GWENHYWFAR_LIBLOADER_P_H */
